@@ -27,10 +27,10 @@ EXPECTED_ERRORS = {
     'deprecated-openerp-xml-node': 5,
     'development-status-allowed': 1,
     'duplicate-id-csv': 2,
-    'duplicate-po-message-definition': 2,
+    'duplicate-po-message-definition': 3,
     'duplicate-xml-fields': 9,
     'duplicate-xml-record-id': 2,
-    'external-request-timeout': 47,
+    'external-request-timeout': 51,
     'file-not-used': 6,
     'incoherent-interpreter-exec-perm': 3,
     'invalid-commit': 4,
@@ -78,11 +78,11 @@ EXPECTED_ERRORS = {
     'website-manifest-key-not-valid-uri': 1,
     'character-not-valid-in-resource-link': 2,
     'manifest-maintainers-list': 1,
-    'test-folder-imported': 2,
+    'test-folder-imported': 3,
 }
 
 if six.PY3:
-    EXPECTED_ERRORS['unnecessary-utf8-coding-comment'] = 19
+    EXPECTED_ERRORS['unnecessary-utf8-coding-comment'] = 18
 else:
     EXPECTED_ERRORS['no-utf8-coding-comment'] = 7
 
@@ -473,6 +473,16 @@ def fstring_no_sqli(self):
         real_errors = pylint_res.linter.stats.by_msg
         self.assertDictEqual(real_errors, {'sql-injection': 4})
 
+    def test_150_check_only_enabled_one_check(self):
+        """Checking -d all -e ONLY-ONE-CHECK"""
+        disable = '--disable=all'
+        for expected_error_name, expected_error_value in EXPECTED_ERRORS.items():
+            enable = '--enable=%s' % expected_error_name
+            pylint_res = self.run_pylint(self.paths_modules, [disable, enable])
+            real_errors = pylint_res.linter.stats.by_msg
+            expected_errors = {expected_error_name: expected_error_value}
+            self.assertDictEqual(real_errors, expected_errors)
+
 
 if __name__ == '__main__':
     unittest.main()
